@@ -40,12 +40,6 @@ class LoginHandler(ClientBaseHandler):
         anonymous_code = self.get_param("anonymous_code", "")
         pt = self.get_param("pt", "tb")  #tb淘宝 tt抖音 wx微信 qq h5
 
-        app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id)
-        if not app_info_dict:
-            return self.response_json_error("error","小程序不存在")
-        if RiskManageHelper.check_current_limit(app_id, app_info_dict["current_limit_count"]) == True:
-            return self.response_json_error("current_limit", "登录失败")
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -148,7 +142,7 @@ class CheckIsMemberHandler(ClientBaseHandler):
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
         if not app_info_dict:
             return self.response_json_error("error", "小程序不存在")
         access_token = app_info_dict["access_token"]
@@ -176,7 +170,7 @@ class GetCrmIntegralHandler(ClientBaseHandler):
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
         if not app_info_dict:
             return self.response_json_error("error", "小程序不存在")
         access_token = app_info_dict["access_token"]
@@ -368,7 +362,7 @@ class GetJoinMemberUrlHandler(ClientBaseHandler):
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
         if not app_info_dict:
             return self.response_json_error("error", "小程序不存在")
         app_key, app_secret = self.get_app_key_secret()
