@@ -10,6 +10,8 @@
 from seven_framework.web_tornado.base_handler.base_api_handler import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.libs.customize.cryptography_helper import *
+from seven_cloudapp_frame.libs.customize.riskmanage_helper import *
+from seven_cloudapp_frame.models.app_base_model import *
 from urllib.parse import parse_qs
 
 
@@ -52,6 +54,27 @@ def filter_check_params(must_params=None, check_user_code=False):
     return check_params
 
 
+def filter_check_current_limit():
+    """
+    :description: 流量限制过滤装饰器 仅限handler使用
+    :last_editors: HuangJianYi
+    """
+    def check_current(handler):
+        def wrapper(self, **args):
+            app_base_model = AppBaseModel(context=self)
+            app_id = self.get_app_id()
+            app_info_dict = app_base_model.get_app_info_dict(app_id,True,"current_limit_count")
+            if app_info_dict and RiskManageHelper.check_current_limit(app_id, app_info_dict["current_limit_count"]) == True:
+                self.response_json_error("current_limit", "系统繁忙,请稍后再试")
+                return
+
+            return handler(self, **args)
+
+        return wrapper
+
+    return check_current
+
+
 def filter_check_head_sign(is_check=True, no_check_params=None):
     """
     :description: 头部过滤装饰器 仅限handler使用
