@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2022-10-17 18:57:31
+@LastEditTime: 2022-10-28 11:47:23
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -13,12 +13,14 @@ from seven_cloudapp_frame.libs.customize.oss2_helper import *
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_login_log_model import *
+from seven_cloudapp_frame.models.db_models.price.price_gear_model import *
 
 
 class LoginHandler(ClientBaseHandler):
     """
     :description: 登录处理
     """
+
     @filter_check_params("open_id")
     def get_async(self):
         """
@@ -76,6 +78,7 @@ class UpdateUserStatusHandler(ClientBaseHandler):
     """
     :description: 更新用户状态
     """
+
     @filter_check_params(check_user_code=True)
     def get_async(self):
         """
@@ -94,7 +97,7 @@ class UpdateUserStatusHandler(ClientBaseHandler):
         user_base_model = UserBaseModel(context=self)
         invoke_result_data = user_base_model.update_user_state(app_id, act_id, user_id, user_state)
         if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         title = "更新用户状态；"
         if user_state == 0:
             title = "解锁用户；"
@@ -109,6 +112,7 @@ class UpdateUserStatusByBlackHandler(ClientBaseHandler):
     """
     :description: 用户拉入黑名单(黑名单管理模式)
     """
+
     @filter_check_params(check_user_code=True)
     def get_async(self):
         """
@@ -128,7 +132,7 @@ class UpdateUserStatusByBlackHandler(ClientBaseHandler):
         user_base_model = UserBaseModel(context=self)
         invoke_result_data = user_base_model.update_user_state_by_black(app_id, act_id, user_id)
         if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         title = "拉黑用户；用户昵称：" + invoke_result_data.data["user_nick"] + "，openid：" + invoke_result_data.data["open_id"]
         self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_info_tb", title=title)
         ref_params = {}
@@ -140,6 +144,7 @@ class AuditUserBlackHandler(ClientBaseHandler):
     """
     :description 审核黑名单状态
     """
+
     @filter_check_params("black_id,audit_status")
     def get_async(self):
         """
@@ -161,7 +166,7 @@ class AuditUserBlackHandler(ClientBaseHandler):
         user_base_model = UserBaseModel(context=self)
         invoke_result_data = user_base_model.audit_user_black(app_id, black_id, audit_status, audit_remark)
         if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         title = "操作审核黑名单；"
         if audit_status == 2:
             title = "同意解锁用户；"
@@ -178,6 +183,7 @@ class UpdateAuditRemarkHandler(ClientBaseHandler):
     """
     :description 修改审核备注
     """
+
     @filter_check_params("black_id,audit_status")
     def get_async(self):
         """
@@ -203,6 +209,7 @@ class UserBlackListHandler(ClientBaseHandler):
     """
     :description: 获取黑名单管理列表
     """
+
     def get_async(self):
         """
         :description: 获取黑名单管理列表
@@ -238,7 +245,8 @@ class UpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 变更资产
     """
-    @filter_check_params("asset_type,asset_value",check_user_code=True)
+
+    @filter_check_params("asset_type,asset_value", check_user_code=True)
     def post_async(self):
         """
         :description: 变更资产
@@ -260,26 +268,34 @@ class UpdateUserAssetHandler(ClientBaseHandler):
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
         user_base_model = UserBaseModel(context=self)
         user_info_dict = user_base_model.get_user_info_dict(app_id, act_id, user_id)
         if not user_info_dict:
-            return self.response_json_error("error","用户信息不存在")
+            return self.response_json_error("error", "用户信息不存在")
 
         asset_base_model = AssetBaseModel(context=self)
         invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
         if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
-        title = "资产配置；"
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        default_prefix = "资产配置；"
+        operation_desc = ""
         if asset_type == 1:
-            title = "次数配置；"
+            default_prefix = "次数配置；"
         elif asset_type == 2:
-            title = "积分配置；"
+            default_prefix = "积分配置；"
         elif asset_type == 3:
-            title = "价格档位配置；"
-        title = title + "用户昵称：" + user_info_dict["user_nick"] + "，openid：" + user_info_dict["open_id"]
-        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_asset_tb", title=title)
+            default_prefix = "价格档位配置；"
+            price_gear_model = PriceGearModel(context=self)
+            asset_object_id = int(asset_object_id)
+            if asset_object_id > 0:
+                price_gear = price_gear_model.get_entity_by_id(asset_object_id)
+                if price_gear:
+                    operation_desc = "价格档位:" + price_gear.price_gear_name + "，次数：" + str(asset_value)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
+        title = title_prefix + "用户昵称：" + user_info_dict["user_nick"] + "，openid：" + user_info_dict["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_asset_tb", title=title, operation_desc=operation_desc)
         ref_params = {}
         self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
@@ -289,7 +305,8 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 批量变更资产
     """
-    @filter_check_params("asset_object_json",check_user_code=True)
+
+    @filter_check_params("asset_object_json", check_user_code=True)
     def post_async(self):
         """
         :description: 批量变更资产
@@ -315,7 +332,7 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
         asset_object_json = SevenHelper.json_loads(asset_object_json)
         asset_object_ids = ""
         for asset_object in asset_object_json:
-            invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], int(asset_object["asset_type"]), int(asset_object["asset_value"]), asset_object["asset_object_id"], 3, "", "手动配置", "手动配置",handler_name = self.__class__.__name__,request_code = self.request_code)
+            invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], int(asset_object["asset_type"]), int(asset_object["asset_value"]), asset_object["asset_object_id"], 3, "", "手动配置", "手动配置", handler_name=self.__class__.__name__, request_code=self.request_code)
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message, asset_object_ids)
             else:
@@ -331,6 +348,7 @@ class UserAssetListHandler(ClientBaseHandler):
     """
     :description: 获取用户资产列表
     """
+
     @filter_check_params(check_user_code=True)
     def get_async(self):
         """
@@ -357,6 +375,7 @@ class AssetLogListHandler(ClientBaseHandler):
     """
     :description: 资产流水记录
     """
+
     def get_async(self):
         """
         :description: 资产流水记录
@@ -409,6 +428,7 @@ class UserInfoListHandler(ClientBaseHandler):
     """
     :description: 用户信息列表
     """
+
     def get_async(self):
         """
         :description: 用户信息列表
