@@ -30,6 +30,71 @@ class WeChatHelper:
     :description: 微信帮助类 1.临时登录凭证校验获取open_id、session_key  2.解析加密数据
     """
     logger_error = Logger.get_logger_by_name("log_error")
+    
+    @classmethod
+    def get_web_authorize_url(self, app_id, redirect_uri, scope="snsapi_userinfo", state="1"):
+        """
+        :description:获取网页授权链接
+        :param app_id：公众号的唯一标识
+        :param redirect_uri：授权后重定向的回调地址，请使用urlencode对链接进行处理
+        :param scope：应用授权作用域，snsapi_base （不弹出授权页面，直接跳转，只能获取用户openid），snsapi_userinfo （弹出授权页面，可通过openid拿到昵称、性别、所在地。并且，即使在未关注的情况下，只要用户授权，也能获取其信息）
+        :param state：重定向后会带上state参数，开发者可以填写a-zA-Z0-9的参数值，最多128字节
+        :return: 返回网页授权链接
+        :last_editors: HuangJianYi
+        """
+        authorize_url = "https://open.weixin.qq.com/connect/oauth2/authorize?appid={0}&redirect_uri={1}&response_type=code&scope={2}&state={3}&connect_redirect=1#wechat_redirect".format(app_id,CodingHelper.url_encode(redirect_uri),scope,CodingHelper.url_encode(state))
+        return authorize_url
+
+    @classmethod
+    def get_web_authorize_userinfo(self, code, grant_type="authorization_code", app_id="", app_secret=""):
+        """
+        :description:获取网页授权用户信息
+        :param code：登录票据
+        :param grant_type：授权方式
+        :param app_id：公众号的唯一标识
+        :param app_secret：公众号的appsecret
+        :return: 返回用户信息{ "openid": "OPENID","nickname": NICKNAME,"sex": 1,"province":"PROVINCE","city":"CITY","country":"COUNTRY","headimgurl":"https://thirdwx.qlogo.cn/mmopen/g3MonUZtNHkdmzicIlibx6iaFqAc56vxLSUfpb6n5WKSYVY0ChQKkiaJSgQ1dZuTOgvLLrhJbERQQ4eMsv84eavHiaiceqxibJxCfHe/46","privilege":[ "PRIVILEGE1" "PRIVILEGE2"],"unionid": "o6_bmasdasdsad6_2sgVt7hMZOPfL"}
+        :last_editors: HuangJianYi
+        """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        invoke_result_data = InvokeResultData()
+        param = {
+            'code': code,  # 用户点击按钮跳转到微信授权页, 微信处理完后重定向到redirect_uri, 并给我们加上code=xxx的参数, 这个code就是我们需要的
+            'appid': app_id,
+            'secret': app_secret,
+            'grant_type': grant_type,
+        }
+
+        # 通过code获取access_token
+        requset_url = 'https://api.weixin.qq.com/sns/oauth2/access_token'
+        response = None
+        try:
+            response = requests.get(requset_url, params=param)
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
+                return invoke_result_data
+            open_id = response_data['openid']
+            access_token = response_data['access_token']
+            requset_url = "https://api.weixin.qq.com/sns/userinfo"
+            response = requests.get(requset_url, params={'access_token':access_token,'openid':open_id,'lang':"zh_CN"})
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
+                return invoke_result_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【get_web_authorize_userinfo】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
 
     @classmethod
     def code2_session(self, code, grant_type="authorization_code", app_id="", app_secret=""):
@@ -59,7 +124,7 @@ class WeChatHelper:
             'grant_type': grant_type,
         }
 
-        # 通过code获取access_token
+        # 通过code获取sessionkey
         requset_url = 'https://api.weixin.qq.com/sns/jscode2session'
         response = None
         try:
