@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 17:17:08
-@LastEditTime: 2022-07-07 14:57:06
+@LastEditTime: 2022-10-27 17:08:11
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -35,9 +35,9 @@ class AssetLog:
         self.user_nick = ""  # 昵称
         self.log_title = ""  # 标题
         self.info_json = ""  # 详情信息
-        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位，业务自定义类型从101起，避免跟公共冲突)
+        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位4-运费券，业务自定义类型从101起，避免跟公共冲突)
         self.asset_object_id = ""  # 资产对象标识（比如资产类型是价格档位则对应档位id）
-        self.source_type = 0  # 来源类型（1-购买2-任务3-手动配置4-抽奖5-回购.业务自定义类型从101起，避免跟公共冲突）
+        self.source_type = 0  # 来源类型（1-购买2-任务3-手动配置4-抽奖5-回购6-兑换.业务自定义类型从101起，避免跟公共冲突）
         self.source_object_id = ""  # 来源对象标识(比如来源类型是任务则对应任务类型)
         self.source_object_name = ""  # 来源对象名称(比如来源类型是任务则对应任务名称)
         self.only_id = ""  # 唯一标识(用于并发操作时校验避免重复操作)
