@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2021-11-29 14:10:17
+@LastEditTime: 2022-10-27 16:48:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -38,7 +38,7 @@ class PrizeRoster:
         self.module_id = 0  # 活动模块标识
         self.module_name = ""  # 活动模块名称
         self.goods_type = 0  # 物品类型（1虚拟2实物）
-        self.prize_type = 0  # 奖品类型(1现货2优惠券3红包4参与奖5预售)
+        self.prize_type = 0  # 奖品类型(1现货2优惠券3红包4参与奖5预售6积分7卡片)业务自定义从101开始
         self.prize_id = 0  # 奖品标识
         self.prize_name = ""  # 奖品名称
         self.prize_pic = ""  # 奖品图
