@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 10:59:39
-@LastEditTime: 2022-01-24 10:14:47
+@LastEditTime: 2022-07-20 14:11:07
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -36,15 +36,20 @@ class UserAccount:
         self.user_state = 0  # 用户状态（0-正常，1-黑名单）
         self.full_name = ""  # 姓名
         self.telephone = ""  #电话号码
+        self.sex = 0  #性别（1-男，2-女）
+        self.birthday = "1900-01-01"  #生日
         self.certificate_type = 1  #证件类型(1身份证2军官证)
         self.certificate_no = "" #证件号码
         self.relieve_date = "1900-01-01 00:00:00"  # 解禁时间
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
+        self.create_ip = "" #创建IP
         self.modify_date = "1900-01-01 00:00:00"  # 修改时间
+        self.login_date = "1900-01-01 00:00:00"  # 登录时间
+        self.login_ip = "" #登录IP
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'union_id', 'open_id', 'user_nick', 'user_nick_encrypt', 'avatar', 'user_state','full_name','telephone','certificate_type','certificate_no', 'relieve_date', 'create_date', 'modify_date']
+        return ['id', 'union_id', 'open_id', 'user_nick', 'user_nick_encrypt', 'avatar', 'user_state','full_name','telephone','sex','birthday','certificate_type','certificate_no', 'relieve_date', 'create_date','create_ip', 'modify_date','login_date','login_ip']
 
     @classmethod
     def get_primary_key(self):
