@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-12-20 16:07:52
-@LastEditTime: 2022-10-19 14:55:28
+@LastEditTime: 2022-11-08 11:10:37
 @LastEditors: HuangJianYi
 @Description: 操作日志相关处理业务模型
 """
@@ -24,7 +24,7 @@ class OperateBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def add_operation_log(self, operation_type, title, operation_desc, model_name, handler_name, old_detail, update_detail, app_id, act_id, operate_user_id, operate_user_name, operate_role_id, request_dict, ip , request_code):
+    def add_operation_log(self, operation_type, title, operation_desc, model_name, handler_name, old_detail, update_detail, app_id, act_id, operate_user_id, operate_user_name, operate_role_id, request_dict, ip , request_code, add_action_to_title=True):
         """
         :description: 创建操作日志
         :param operation_type：操作类型（查看枚举类OperationType）
@@ -41,6 +41,7 @@ class OperateBaseModel():
         :param operate_role_id：操作人角色标识
         :param ip：ip地址
         :param request_code：请求代码
+        :param add_action_to_title:标题追加操作类型名称（True是False否）
         :return: 
         :last_editors: HuangJianYi
         """
@@ -66,7 +67,10 @@ class OperateBaseModel():
         operation_log.operate_role_id = operate_role_id
         operation_log.operate_user_id = operate_user_id
         operation_log.operate_user_name = operate_user_name
-        operation_log.title = title
+        if add_action_to_title == True:
+            operation_log.title = self.get_operation_type_name(operation_type) + title if operation_type != 10 else title
+        else:
+            operation_log.title = title
         operation_log.operation_desc = operation_desc
         operation_log.create_date = TimeHelper.get_now_format_time()
         operation_log.create_day = SevenHelper.get_now_day_int()
@@ -171,12 +175,16 @@ class OperateBaseModel():
                 default = config_fields.get("value", {}).get("default", "")
                 if default:
                     value_remark = default.replace("{0}", str(value))
+                elif ',' in value:
+                    for item in value.split(','):
+                        cur_remark = config_fields.get("value", {}).get(str(item), "")
+                        if cur_remark:
+                            value_remark = "" if value_remark == "-" else value_remark
+                            value_remark += "," + cur_remark if value_remark != "" else cur_remark
                 else:
                     value_remark = config_fields.get("value", {}).get(str(value), "-")
-            elif value != "":
-                value_remark = value
             else:
-                value_remark = "-"
+                value_remark = value
         return value_remark
         
     def get_contrast_info(self, operation_log, is_all_fields=False):
@@ -233,3 +241,33 @@ class OperateBaseModel():
             elif self.logging_link_error:
                 self.logging_link_error("【获取操作日志对比信息】" + traceback.format_exc())
         return operation_log
+    
+    def get_operation_type_name(self, operation_type):
+        """
+        :description:  获取操作类型名称
+        :param operation_type:操作类型
+        :return : 
+        :last_editors: HuangJianYi
+        """
+        if operation_type == 1:
+            return "新增"
+        elif operation_type == 2:
+            return "编辑"
+        elif operation_type == 3:
+            return "删除"
+        elif operation_type == 4:
+            return "还原"
+        elif operation_type == 5:
+            return "复制"
+        elif operation_type == 6:
+            return "导出"
+        elif operation_type == 7:
+            return "导入"
+        elif operation_type == 8:
+            return "上架"
+        elif operation_type == 9:
+            return "下架"
+        elif operation_type == 10:
+            return "操作"
+        else:
+            return ""
\ No newline at end of file
