@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-10-17 16:19:57
+@LastEditTime: 2022-11-14 14:56:08
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -155,7 +155,7 @@ class UserBaseModel(FrameBaseModel):
         top_base_model = TopBaseModel(context=self.context)
         return top_base_model.get_join_member_url(access_token, app_key, app_secret, is_log)
 
-    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id="",login_ip=""):
+    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id="", login_ip="", is_update_user_nick=True):
         """
         :description: 获取或更新用户信息（主要用于登录）
         :param app_id：应用标识
@@ -165,6 +165,7 @@ class UserBaseModel(FrameBaseModel):
         :param avatar：头像
         :param union_id：union_id
         :param login_ip：登录ip地址
+        :param is_update_user_nick：是否更新用户昵称
         :return: 返回用户信息
         :last_editors: HuangJianYi
         """
@@ -205,7 +206,7 @@ class UserBaseModel(FrameBaseModel):
                 user_account.login_ip = login_ip
                 user_account.id = user_account_model.add_entity(user_account)
             else:
-                if user_nick and user_account.user_nick != user_nick:
+                if user_nick and user_account.user_nick != user_nick and is_update_user_nick == True:
                     user_account.user_nick = CryptographyHelper.emoji_to_emoji_base64(user_nick)
                     user_account.user_nick_encrypt = CryptographyHelper.base64_encrypt(user_nick)
                 if avatar and user_account.avatar != avatar:
